@@ -3,13 +3,23 @@
 
 use v5.37.12;
 
+use lib "$ENV{HOME}/Zoom-Meeting/lib";
+use lib "$ENV{HOME}/perl5/lib/perl5";
+# use lib '/usr/local/lib/perl5/5.37.12/';
+
 use Zoom::Meeting;
 
-my $zoom = Zoom::Meeting -> new (id => '', password => '');
+my $zoom = Zoom::Meeting -> new (id => '0' x 11);
+# Create object with required ID
+
+say $zoom -> password('NEW_PASS');
+# Set password via a method call
 
 say $zoom;
+# Show the URL
 
 $zoom -> launch;
+# Launch Windows Zoom from WSL
 
 __END__
 
@@ -23,7 +33,7 @@ zoom.pl - Example script to launch Zoom
 
 =head1 VERSION
 
-version 0.231550
+version 0.231570
 
 =head1 AUTHOR
 
