@@ -18,6 +18,28 @@ class Zoom::Meeting {
   field $password :param = undef;
   # @formatter:on
 
+
+  method id ( $new_id = undef ) {
+    if ( defined $new_id ) {
+      $id = $new_id;
+    }
+    else {
+      return $id;
+    }
+  }
+
+
+
+  method password ( $new_password = undef ) {
+    if ( defined $new_password ) {
+      $password = $new_password;
+    }
+    else {
+      return $password;
+    }
+  }
+
+
   method _url ( ) {
     my $uri = URI -> new( 'zoommtg://zoom.us' ); # scheme is '_foreign' class, so no 'host' method
     $uri -> path( 'join' );
@@ -28,6 +50,8 @@ class Zoom::Meeting {
     return $uri;
   }
 
+
+
   method launch ( ) {
 
     my $zoom;
@@ -44,6 +68,7 @@ class Zoom::Meeting {
 
   }
 
+
 }
 
 __END__
@@ -58,7 +83,34 @@ Zoom::Meeting - Launch Zoom meetings via Perl
 
 =head1 VERSION
 
-version 0.231550
+version 0.231570
+
+=head1 METHODS
+
+=head2 new
+
+Constructor method used to create a C<Zoom::Meeting> object
+
+Accepts C<id> and C<password> parameters to initialize its fields
+
+=head2 id([$new_id])
+
+Return or set meeting ID
+
+=head2 password([$new_password])
+
+Return or set meeting password
+
+=head2 _url
+
+Private method constructing Zoom URL containing C<confno> and C<pwd> fields
+standing for meeting ID and password respectively
+
+=head2 launch()
+
+Launch the Zoom meeting object in a Zoom application
+
+Supports only WSL currently, Linux and native Windows support to be added
 
 =head1 AUTHOR
 
